@@ -1,7 +1,7 @@
 """
 Type annotations for kms service literal definitions.
 
-[Open documentation](./literals.md)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_kms/literals.html)
 
 Usage::
 
@@ -37,6 +37,7 @@ __all__ = (
     "ListKeyPoliciesPaginatorName",
     "ListKeysPaginatorName",
     "MessageTypeType",
+    "MultiRegionKeyTypeType",
     "OriginTypeType",
     "SigningAlgorithmSpecType",
     "WrappingKeySpecType",
@@ -97,13 +98,23 @@ GrantOperationType = Literal[
     "Verify",
 ]
 KeyManagerTypeType = Literal["AWS", "CUSTOMER"]
-KeyStateType = Literal["Disabled", "Enabled", "PendingDeletion", "PendingImport", "Unavailable"]
+KeyStateType = Literal[
+    "Creating",
+    "Disabled",
+    "Enabled",
+    "PendingDeletion",
+    "PendingImport",
+    "PendingReplicaDeletion",
+    "Unavailable",
+    "Updating",
+]
 KeyUsageTypeType = Literal["ENCRYPT_DECRYPT", "SIGN_VERIFY"]
 ListAliasesPaginatorName = Literal["list_aliases"]
 ListGrantsPaginatorName = Literal["list_grants"]
 ListKeyPoliciesPaginatorName = Literal["list_key_policies"]
 ListKeysPaginatorName = Literal["list_keys"]
 MessageTypeType = Literal["DIGEST", "RAW"]
+MultiRegionKeyTypeType = Literal["PRIMARY", "REPLICA"]
 OriginTypeType = Literal["AWS_CLOUDHSM", "AWS_KMS", "EXTERNAL"]
 SigningAlgorithmSpecType = Literal[
     "ECDSA_SHA_256",
